@@ -21,7 +21,6 @@ void SourceOutput::update(const pa_source_output_info *info)
     if (m_deviceIndex != info->source) {
         m_deviceIndex = info->source;
         Q_EMIT deviceIndexChanged();
-        Q_EMIT sourceIndexChanged();
     }
 }
 
@@ -50,9 +49,4 @@ void SourceOutput::setChannelVolumes(const QVector<qint64> &channelVolumes)
     context()->setGenericVolumes(index(), channelVolumes, cvolume(), &pa_context_set_source_output_volume);
 }
 
-quint32 SourceOutput::sourceIndex() const
-{
-    return m_deviceIndex;
-}
-
 } // QPulseAudio
